@@ -1,16 +1,23 @@
 `EstDimRMT` <-
 function(data.m){
  ### standardise matrix
- M <- data.m;
- for(c in 1:ncol(M)){
-  M[,c] <- (data.m[,c]-mean(data.m[,c]))/sqrt(var(data.m[,c]));
- }
+ M <- apply(data.m,2,function(X){ (X - mean(X))/sqrt(var(X))});
+ 
  sigma2 <- var(as.vector(M));
  Q <- nrow(data.m)/ncol(data.m);
+ ns <- ncol(data.m);
  lambdaMAX <- sigma2*(1+1/Q + 2*sqrt(1/Q));
  lambdaMIN <- sigma2*(1+1/Q - 2*sqrt(1/Q));
  delta <- lambdaMAX - lambdaMIN;#  print(delta);
- step <- round(delta/ncol(data.m),3);
+
+ roundN <- 3;
+ step <- round(delta/ns,roundN);
+ while(step==0){
+    roundN <- roundN+1;
+    step <- round(delta/ns,roundN);
+ }
+  
+
  lambda.v <- seq(lambdaMIN,lambdaMAX,by=step);
  dens.v <- vector();
  ii <- 1;
