@@ -21,9 +21,11 @@ function(data.m,pheno.v,ncomp=NULL){
   ### now construct ISV
   tmp.m <- t(fICA.o$A);
   isv.m <- tmp.m;
+  sd <- 1/sqrt(ncol(data.m)-3);
   for(k in 1:ncol(tmp.m)){
-   lm.o <- summary(lm(t(data.m) ~ tmp.m[,k]));
-   pv.v <- unlist(lapply(lm.o,function(x){ x$coeff[2,4]}));
+   cor.v <- as.vector(cor(t(data.m),tmp.m[, k]))
+   z.v <- 0.5*log((1+cor.v)/(1-cor.v));
+   pv.v <- 2*pnorm(abs(z.v),0,sd,lower.tail=FALSE)
    tmp.s <- sort(pv.v,decreasing=FALSE,index.return=TRUE);
    qv.o <- qvalue(pv.v);
    nsig <- length(which(qv.o$qvalues<0.05));
